VirtualHost class abstract

A utility for handling multiple hosts on multiple sources using a named-based approach.

Constructors

VirtualHost([Stream<HttpRequest>? source])
Construct an VirtualHost with an optional initial source.
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unhandled → Stream<HttpRequest>
The Stream of HttpRequest not matching any hosts.
no setter

Methods

addHost(String host) → Stream<HttpRequest>
Add a host to the VirtualHost instance.
addSource(Stream<HttpRequest> source) → void
Provide another source of HttpRequests in the form of a Stream.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited